eric7/UI/Browser.py

branch
unittest
changeset 9066
a219ade50f7c
parent 8925
8375eb895f70
--- a/eric7/UI/Browser.py	Mon May 16 17:22:43 2022 +0200
+++ b/eric7/UI/Browser.py	Mon May 16 19:46:51 2022 +0200
@@ -69,7 +69,7 @@
     @signal svgFile(filename) emitted to open a SVG file (str)
     @signal umlFile(filename) emitted to open an eric UML file (str)
     @signal binaryFile(filename) emitted to open a file as binary (str)
-    @signal unittestOpen(filename) emitted to open a Python file for a
+    @signal testFile(filename) emitted to open a Python file for a
         unit test (str)
     """
     sourceFile = pyqtSignal((str, ), (str, int), (str, list), (str, int, str))
@@ -83,7 +83,7 @@
     svgFile = pyqtSignal(str)
     umlFile = pyqtSignal(str)
     binaryFile = pyqtSignal(str)
-    unittestOpen = pyqtSignal(str)
+    testFile = pyqtSignal(str)
     
     def __init__(self, parent=None):
         """
@@ -138,7 +138,7 @@
             """ suffix) are identified in the hierarchies with a Python"""
             """ icon. The right mouse button will popup a menu which lets"""
             """ you open the file in a Source Viewer window, open the file"""
             """ for debugging or use it for a unittest run.</p>"""
             """<p>The context menu of a class, function or method allows you"""
             """ to open the file defining this class, function or method and"""
             """ will ensure, that the correct source line is visible.</p>"""
@@ -232,9 +232,9 @@
         self.sourceMenu = QMenu(self)
         self.sourceMenu.addAction(
             QCoreApplication.translate('Browser', 'Open'), self._openItem)
-        self.unittestAct = self.sourceMenu.addAction(
-            QCoreApplication.translate('Browser', 'Run unittest...'),
-            self.handleUnittest)
+        self.testingAct = self.sourceMenu.addAction(
+            QCoreApplication.translate('Browser', 'Run Test...'),
+            self.handleTesting)
         self.sourceMenu.addSeparator()
         self.mimeTypeAct = self.sourceMenu.addAction(
             QCoreApplication.translate('Browser', 'Show Mime-Type'),
@@ -399,9 +399,9 @@
                 if isinstance(itm, BrowserFileItem):
                     if itm.isPython3File():
                         if itm.fileName().endswith('.py'):
-                            self.unittestAct.setEnabled(True)
+                            self.testingAct.setEnabled(True)
                         else:
-                            self.unittestAct.setEnabled(False)
+                            self.testingAct.setEnabled(False)
                         self.sourceMenu.popup(coord)
                     else:
                         self.editPixmapAct.setVisible(itm.isPixmapFile())
@@ -640,9 +640,9 @@
         # remember the current state
         Preferences.setUI("BrowsersListHiddenFiles", checked)
     
-    def handleUnittest(self):
+    def handleTesting(self):
         """
         Public slot to handle the unittest popup menu entry.
         """
         try:
             index = self.currentIndex()
@@ -652,7 +652,7 @@
             pyfn = None
 
         if pyfn is not None:
-            self.unittestOpen.emit(pyfn)
+            self.testFile.emit(pyfn)
         
     def __newToplevelDir(self):
         """
@@ -138,7 +138,7 @@
             """ icon. The right mouse button will popup a menu which lets"""
             """ you open the file in a Source Viewer window, open the file"""
-            """ for debugging or use it for a unittest run.</p>"""
+            """ for debugging or use it for a test run.</p>"""
             """<p>The context menu of a class, function or method allows you"""
             """ to open the file defining this class, function or method and"""
@@ -640,9 +640,9 @@
         """
-        Public slot to handle the unittest popup menu entry.
+        Public slot to handle the testing popup menu entry.
         """
         try:

eric ide

mercurial